agentle.agents.knowledge.url\_knowledge
=======================================

.. automodule:: agentle.agents.knowledge.url_knowledge

   
   .. rubric:: Functions

   .. autosummary::
   
      Field
   
   .. rubric:: Classes

   .. autosummary::
   
      AnyUrl
      BaseModel
      UrlKnowledge
   